==> custom_pages-v1.12.8.zip: custom_pages/messages/nb-NO/base.php <==
<?php

return [
    '<strong>Add</strong> {templateName} item' => '<strong>Legg til</strong> {templateName} element',
    '<strong>Custom</strong> Pages' => '<strong>Egne</strong> sider',
    '<strong>Edit</strong> snippet' => '<strong>Rediger</strong> infobox',
    'Add' => 'Legg til',
    'Add a file icon before the title' => 'Legg til ikon foran tittel',
    'Adds plain HTML content to your site.' => 'Legger til ren HTML til din side',
    'Advanced' => 'Avansert',
    'Allows to add pages (markdown, iframe or links) to the space navigation' => 'Tillater å legge til sider (markdown, iframe eller lenker) til gruppenavigasjon',
    'Allows you to add content in MarkDown syntax.' => 'Lar deg legge til innhold i MarkDown syntaks',
    'Alternate text' => 'Alternativ text',
    'Always' => 'Alltid',
    'Always make a backup of your view files outside of your production environment!' => 'Lag alltid en backup av dine visningsfiler utenfor produksjonsmiljøet.',
    'An empty allowed template selection will allow all container templates for this container.' => 'La denne stå tom hvis du vil tillate alle Container maler for denne Containeren.',
    'Back' => 'Tilbake',
    'Back to dashboard' => 'Tilbake til Aktivitetskalenderen',
    'Back to overview' => 'Tilbake til listen',
    'Back to space' => 'Tilbake til gruppe',
    'Category' => 'Kategori',
    'Configuration' => 'Konfigurasjon',
    'Content' => 'Innhold',
    'Create' => 'Lag',
    'Css Class' => 'Css klasse',
    'Custom' => 'Tilpasset',
    'Custom Pages' => 'Egne sider',
    'Custom pages' => 'Egne sider',
    'Dashboard' => 'Oversikt',
    'Default' => 'Standard',
    'Default Content' => 'Standardinnhold',
    'Delete' => 'Slett',
    'Edit' => 'Rediger',
    'Edit Page' => 'Rediger side',
    'Empty' => 'Tom',
    'File' => 'Fil',
    'General' => 'Generelt',
    'Html' => 'Html',
    'ID' => 'ID',
    'Icon' => 'Ikon',
    'Iframe' => 'Iframe',
    'Insert' => 'Sett inn',
    'Invalid request data!' => 'Dataene som er forespurt er ugyldige',
    'Invalid template selection!' => 'Ugyldig utvalg for mal.',
    'Invalid type selection' => 'Ugyldig valg for type',
    'Invalid view file selection!' => 'Ugyldig utvalg for visningsfil.',
    'Link' => 'Link',
    'MarkDown' => 'MarkDown',
    'Navigation' => 'Navigering',
    'On this page you can configure general settings of your custom pages.' => 'Her konfigurerer du generelle innstillinger for dine Egne sider.',
    'Overview' => 'Oversikt',
    'PHP' => 'PHP',
    'Pages' => 'Sider',
    'Please keep in mind that php based pages are vulnerable to security issues, especially when handling user input. For more information, please have a look at <a href="{url}">Yii\'s Security best practices</a>.' => 'Vær oppmerksom på at sider basert på php kan være sårbare mhp sikkehet, spesielt ved håndtering av bruker-input. For mer informasjon, se  <a href="%7Burl%7D">Yii\'s Security best practices</a>.',
    'Public' => 'Offentlig',
    'Reset' => 'Reset',
    'Settings' => 'Innstillinger',
    'Show additional file information (size)' => 'Vis tilleggsinformasjon for fil (størrelse)',
    'Snippet' => 'Snippet',
    'Snippets' => 'Infoboxer (snippet)',
    'Sort Order' => 'Sorteringsrekkefølge',
    'Source' => 'Kilde',
    'Space' => 'Gruppe',
    'Spaces' => 'Grupper',
    'Stream' => 'Nyhetsstrøm',
    'Style' => 'Stil',
    'Style Class' => 'Stil-klasse',
    'Submit' => 'Send',
    'Target Url' => 'Mål url',
    'Template' => 'Mal',
    'Template Layout' => 'Mal layout',
    'Templates' => 'Maler',
    'Templates allow you to define combinable page fragments with inline edit functionality.' => 'Maler lar deg definere kombinerbare side-elementer med inline redigeringsmuligheter.',
    'This container does not allow any further items!' => 'Denne konteineren kan ikke ha flere elementer.',
    'Title' => 'Tittel',
    'Top Navigation' => 'Toppnavigering',
    'Topics' => 'Emner',
    'Type' => 'Type',
    'Upload image' => 'Last opp bilde',
    'User Account Menu (Settings)' => 'Brukerkonto meny (Innstillinger)',
    'Visibility' => 'Synlighet',
    'Will embed the result of a given url as an iframe element.' => 'Vil embedde (innbake) resultatet av en gitt url som et iframe element.',
    'Will redirect requests to a given (relative or absolute) url.' => 'Videresender bruker til en gitt (relativ eller absolutt) url.',
    'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.' => 'Med PHP baserte sider kan du lage dine egne sider. Sjekk ut konfigurasjon under modulen for mer informasjon.',
    'Without adding to navigation (Direct link)' => 'Uten å legge til navigering (direkte link)',
    'You are not allowed to delete default content!' => 'Du kan ikke slette standard innhold',
    'Additional IFrame Attributes' => '',
    'Administrative Users' => '',
    'Allows the user to manage custom pages.' => '',
    'Authors' => '',
    'Can manage custom pages' => '',
    'Cannot delete!' => '',
    'Container' => '',
    'Content filters' => '',
    'Deleted.' => '',
    'Empty content elements cannot be deleted!' => '',
    'Enter post content ID' => '',
    'Footer menu' => '',
    'Global Page' => '',
    'Global Widget' => '',
    'Go Back' => '',
    'Import' => '',
    'Layout' => '',
    'Leave empty to list all records related to the current user.' => '',
    'Limit' => '',
    'Logged-In Users' => '',
    'Manage layouts, snippet layouts, and containers. Layouts define page structures, snippet layouts are used in sidebars or sections, and containers are reusable content blocks.' => '',
    'Menu settings' => '',
    'Non-Logged-In Users' => '',
    'Page' => '',
    'Page Content' => '',
    'Panel' => '',
    'People Buttons' => '',
    'Please choose one of the following content types. The content type defines how your content is embedded to your site.' => '',
    'Reset the content to default value' => '',
    'Resources' => '',
    'Restrict to following comma separated content IDs' => '',
    'Select this setting for visible text nodes only. Uncheck this setting in case this element is used for example as HTML attribute value.' => '',
    'Space Members only' => '',
    'Space Navigation' => '',
    'Space Page' => '',
    'Space Widget' => '',
    'Start Page' => '',
    'Stream options' => '',
    'Usage' => '',
    'Wrap this HTML page with white panel' => '',
];

==> custom_pages-v1.12.14.zip: custom_pages/messages/nb-NO/base.php <==
<?php

return [
    '<strong>Add</strong> {templateName} item' => '<strong>Legg til</strong> {templateName} element',
    '<strong>Custom</strong> Pages' => '<strong>Egne</strong> sider',
    '<strong>Edit</strong> snippet' => '<strong>Rediger</strong> infobox',
    'Add' => 'Legg til',
    'Add a file icon before the title' => 'Legg til ikon foran tittel',
    'Adds plain HTML content to your site.' => 'Legger til ren HTML til din side',
    'Advanced' => 'Avansert',
    'Allows to add pages (markdown, iframe or links) to the space navigation' => 'Tillater å legge til sider (markdown, iframe eller lenker) til gruppenavigasjon',
    'Allows you to add content in MarkDown syntax.' => 'Lar deg legge til innhold i MarkDown syntaks',
    'Alternate text' => 'Alternativ text',
    'Always' => 'Alltid',
    'Always make a backup of your view files outside of your production environment!' => 'Lag alltid en backup av dine visningsfiler utenfor produksjonsmiljøet.',
    'An empty allowed template selection will allow all container templates for this container.' => 'La denne stå tom hvis du vil tillate alle Container maler for denne Containeren.',
    'Back' => 'Tilbake',
    'Back to dashboard' => 'Tilbake til Aktivitetskalenderen',
    'Back to overview' => 'Tilbake til listen',
    'Back to space' => 'Tilbake til gruppe',
    'Category' => 'Kategori',
    'Configuration' => 'Konfigurasjon',
    'Content' => 'Innhold',
    'Create' => 'Lag',
    'Css Class' => 'Css klasse',
    'Custom' => 'Tilpasset',
    'Custom Pages' => 'Egne sider',
    'Custom pages' => 'Egne sider',
    'Dashboard' => 'Oversikt',
    'Default' => 'Standard',
    'Default Content' => 'Standardinnhold',
    'Delete' => 'Slett',
    'Edit' => 'Rediger',
    'Edit Page' => 'Rediger side',
    'Empty' => 'Tom',
    'File' => 'Fil',
    'General' => 'Generelt',
    'Html' => 'Html',
    'ID' => 'ID',
    'Icon' => 'Ikon',
    'Iframe' => 'Iframe',
    'Insert' => 'Sett inn',
    'Invalid request data!' => 'Dataene som er forespurt er ugyldige',
    'Invalid template selection!' => 'Ugyldig utvalg for mal.',
    'Invalid type selection' => 'Ugyldig valg for type',
    'Invalid view file selection!' => 'Ugyldig utvalg for visningsfil.',
    'Link' => 'Link',
    'MarkDown' => 'MarkDown',
    'Navigation' => 'Navigering',
    'On this page you can configure general settings of your custom pages.' => 'Her konfigurerer du generelle innstillinger for dine Egne sider.',
    'Overview' => 'Oversikt',
    'PHP' => 'PHP',
    'Pages' => 'Sider',
    'Please keep in mind that php based pages are vulnerable to security issues, especially when handling user input. For more information, please have a look at <a href="{url}">Yii\'s Security best practices</a>.' => 'Vær oppmerksom på at sider basert på php kan være sårbare mhp sikkehet, spesielt ved håndtering av bruker-input. For mer informasjon, se  <a href="%7Burl%7D">Yii\'s Security best practices</a>.',
    'Public' => 'Offentlig',
    'Reset' => 'Reset',
    'Settings' => 'Innstillinger',
    'Show additional file information (size)' => 'Vis tilleggsinformasjon for fil (størrelse)',
    'Snippet' => 'Snippet',
    'Snippets' => 'Infoboxer (snippet)',
    'Sort Order' => 'Sorteringsrekkefølge',
    'Source' => 'Kilde',
    'Space' => 'Gruppe',
    'Spaces' => 'Grupper',
    'Stream' => 'Nyhetsstrøm',
    'Style' => 'Stil',
    'Style Class' => 'Stil-klasse',
    'Submit' => 'Send',
    'Target Url' => 'Mål url',
    'Template' => 'Mal',
    'Template Layout' => 'Mal layout',
    'Templates' => 'Maler',
    'Templates allow you to define combinable page fragments with inline edit functionality.' => 'Maler lar deg definere kombinerbare side-elementer med inline redigeringsmuligheter.',
    'This container does not allow any further items!' => 'Denne konteineren kan ikke ha flere elementer.',
    'Title' => 'Tittel',
    'Top Navigation' => 'Toppnavigering',
    'Topics' => 'Emner',
    'Type' => 'Type',
    'Upload image' => 'Last opp bilde',
    'User Account Menu (Settings)' => 'Brukerkonto meny (Innstillinger)',
    'Visibility' => 'Synlighet',
    'Will embed the result of a given url as an iframe element.' => 'Vil embedde (innbake) resultatet av en gitt url som et iframe element.',
    'Will redirect requests to a given (relative or absolute) url.' => 'Videresender bruker til en gitt (relativ eller absolutt) url.',
    'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.' => 'Med PHP baserte sider kan du lage dine egne sider. Sjekk ut konfigurasjon under modulen for mer informasjon.',
    'Without adding to navigation (Direct link)' => 'Uten å legge til navigering (direkte link)',
    'You are not allowed to delete default content!' => 'Du kan ikke slette standard innhold',
    'Activities' => '',
    'Activity' => '',
    'Activity content ID' => '',
    'Additional IFrame Attributes' => '',
    'Administrative Users' => '',
    'Allows the user to manage custom pages.' => '',
    'Authors' => '',
    'By creation date' => '',
    'By last update' => '',
    'Can manage custom pages' => '',
    'Cannot delete!' => '',
    'Container' => '',
    'Content filters' => '',
    'Deleted.' => '',
    'Determine which Spaces should be taken into account.' => '',
    'Empty content elements cannot be deleted!' => '',
    'Enter post content ID' => '',
    'Footer menu' => '',
    'Global Page' => '',
    'Global Widget' => '',
    'Go Back' => '',
    'Import' => '',
    'Include all Spaces except selected' => '',
    'Include selected Spaces only' => '',
    'Layout' => '',
    'Leave empty to list all records related to the current user.' => '',
    'Limit' => '',
    'Logged-In Users' => '',
    'Manage layouts, snippet layouts, and containers. Layouts define page structures, snippet layouts are used in sidebars or sections, and containers are reusable content blocks.' => '',
    'Menu settings' => '',
    'Non-Logged-In Users' => '',
    'Page' => '',
    'Page Content' => '',
    'Panel' => '',
    'People Buttons' => '',
    'Please choose one of the following content types. The content type defines how your content is embedded to your site.' => '',
    'Reset the content to default value' => '',
    'Resources' => '',
    'Restrict to following comma separated content IDs' => '',
    'Select this setting for visible text nodes only. Uncheck this setting in case this element is used for example as HTML attribute value.' => '',
    'Sorting' => '',
    'Space Members only' => '',
    'Space Navigation' => '',
    'Space Page' => '',
    'Space Widget' => '',
    'Space selection' => '',
    'Start Page' => '',
    'Stream options' => '',
    'Usage' => '',
    'Wrap this HTML page with white panel' => '',
];
